#ifndef _CSS_OBJECTS_H
#define _CSS_OBJECTS_H

#include <sys/stat.h>

#include "gobject/GObject.h"
#include "gobject/CssTable.h"
#include "gobject/Vector.h"
#include "idccss/CssStructures.h"

/******************************************************************************
	To add a table called "mytable", do each of the following:

	1) Add the CSSMytable structure in CssStructures.h
	2) In this file, add the CssMytable typedef struct.
	3) In cssObjects.c, add static bool defineMytable()
	4) In cssObjects.c, add static bool mytableDefined = False;
	5) In cssObjects.c, add new_CssMytable()
	6) In cssObjects.c, add new_CssMytables()
*******************************************************************************/


/**
 *  Arrival structure.
 */
typedef struct CssArrival_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSArrival	c;

	// extra members for gbase internal use
	int	ts_dc;		// associated waveform dc
	int	ts_id;		// associated waveform id
	int	ts_copy;	// associated waveform copy
	char	phase[9];	// associated phase (from an assoc)
	double	amp_cnts;	// measured amplitude
	double	amp_Nnms;	// measured amplitude (nominal)
	double	amp_nms;	// measured amplitude (corrected)
	double	zp_Nnms;	// zp measured amplitude (nominal)
	double	period;		// measured period
	bool	box_location;
	double	boxtime;	// position (time) of the left side of the box
	double	boxmin;		// position (counts) of the bottom side
	int	atype;		// if > -1, points to ArrType
	double	value;		// value to use if using ArrType
	int	pick_file;	// pick filename (complete path)
	int	wftag_file;	// wftag filename (complete path)
	int	filter_file;	// filter filename (complete path)
	int	pick_index;	// index of arrival in pick_file
	int	wftag_index;	// index of arrival in wftag_file
	int	filter_index;	// index of arrival in filter_file
	int	sta_quark;
	int	chan_quark;
	int	net_quark;
} _CssArrival, *CssArrival;

/**
 *  Wfdisc structure.
 */
typedef struct CssWfdisc_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSWfdisc	c;

	int	sta_quark;
	int	chan_quark;
} _CssWfdisc, *CssWfdisc;

/**
 *  History structure.
 */
typedef struct CssHistory_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSHistory	c;
} _CssHistory, *CssHistory;

/**
 *  Channame structure.
 */
typedef struct CssChanname_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSChanname	c;
} _CssChanname, *CssChanname;

/**
 *  Frameproduct structure.
 */
typedef struct CssFrameproduct_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSFrameProduct	c;
} _CssFrameproduct, *CssFrameproduct;

/**
 *  Fpdescription structure.
 */
typedef struct CssFpdescription_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSFpDescription c;
} _CssFpdescription, *CssFpdescription;

/**
 *  md5_digest structure.
 */
typedef struct CssMd5_digest_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSMd5Digest	c;
} _CssMd5_digest, *CssMd5_digest;

/**
 *  clf structure.
 */
typedef struct CssClf_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSClf		c;
} _CssClf, *CssClf;


/**
 *  waveinterval structure.
 */
typedef struct CssWaveinterval_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSWaveInterval c;
} _CssIaveinterval, *CssWaveinterval;

/**
 *  outage structure.
 */
typedef struct CssOutage_s
{
	GObjectPart     core;
	CssTablePart    css;
	CSSOutage	c;
} _CssOutage, *CssOutage;

/**
 *  Origin structure.
 */
typedef struct CssOrigin_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSOrigin	c;

	// extra members for gbase internal use
	int	wftag_file;	// wftag filename (complete path)
	int	origerr_file;	// origerr filename (complete path)
	int	wftag_index;	// index of wftag in wftag_file
	int	origerr_index;	// index of origerr in origerr_file
} _CssOrigin, *CssOrigin;

/**
 *  Origerr structure.
 */
typedef struct CssOrigerr_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSOrigerr	c;
} _CssOrigerr, *CssOrigerr;

/**
 *  Origaux structure.
 */
typedef struct CssOrigaux_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSOrigaux	c;
} _CssOrigaux, *CssOrigaux;

/**
 *  Lastid structure.
 */
typedef struct CssLastid_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSLastid	c;
} _CssLastid, *CssLastid;

/**
 *  Gregion structure.
 */
typedef struct CssGregion_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSGregion	c;
} _CssGregion, *CssGregion;

/**
 *  Sensor structure.
 */
typedef struct CssSensor_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSSensor	c;

	// extra members for gbase internal use
	int	sta_quark;
	int	chan_quark;
} _CssSensor, *CssSensor;

/**
 *  Instrument structure.
 */
typedef struct CssInstrument_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSInstrument	c;
} _CssInstrument, *CssInstrument;

/**
 *  Sitechan structure.
 */
typedef struct CssSitechan_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSSitechan	c;

	// extra members for gbase internal use
	int	sta_quark;
	int	chan_quark;
	int	chan_alt;
} _CssSitechan, *CssSitechan;

/**
 *  Site structure.
 */
typedef struct CssSite_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSSite		c;

	// extra members for gbase internal use
	int	sta_quark;
	int	refsta_quark;
} _CssSite, *CssSite;

/**
 *  Wftag structure.
 */
typedef struct CssWftag_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSWftag	c;
} _CssWftag, *CssWftag;

/**
 *  Xtag structure.
 */
typedef struct CssXtag_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSXtag		c;

	// extra members for gbase internal use
	long	tagid;
	long	wfid;
	double	mintime;
	double	maxtime;
	char	sta[7];
	char	dir[256];
} _CssXtag, *CssXtag;

/**
 *  fsdisc structure.
 */
typedef struct CssFsdisc_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSFsdisc	c;

	int	sta_quark;
	int	chan_quark;
} _CssFsdisc, *CssFsdisc;

/**
 *  fsave structure.
 */
typedef struct CssFsave_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSFsave	c;

	int	sta_quark;
	int	chan_quark;
} _CssFsave, *CssFsave;

/**
 *  fsrecipe structure.
 */
typedef struct CssFsrecipe_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSFsrecipe	c;
} _CssFsrecipe, *CssFsrecipe;

/**
 *  Fstag structure.
 */
typedef struct CssFstag_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSFstag	c;
} _CssFstag, *CssFstag;

/**
 *  Spdisc structure.
 */
typedef struct CssSpdisc_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSSpdisc	c;

	int	sta_quark;
	int	chan_quark;
} _CssSpdisc, *CssSpdisc;

/**
 *  CssDervdisc structure.
 */
typedef struct CssDervdisc_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSDervdisc	c;

	int	sta_quark;
	int	chan_quark;
} _CssDervdisc, *CssDervdisc;

typedef struct CssPmccRecipe_s
{
        GObjectPart     core;
        CssTablePart    css;
	CSSPmccRecipe	c;

	int	sta_quark;
} _CssPmccRecipe, *CssPmccRecipe;


typedef struct CssPmccFeatures_s
{
        GObjectPart     core;
        CssTablePart    css;
	CSSPmccFeatures	c;

	int	sta_quark;
} _CssPmccFeatures, *CssPmccFeatures;

/**
 *  Pick structure.
 */
typedef struct CssPick_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSPick		c;

	int	sta_quark;
	int	chan_quark;
} _CssPick, *CssPick;

/**
 *  Filter structure.
 */
typedef struct CssFilter_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSFilter	c;

	int	sta_quark;
	int	chan_quark;
} _CssFilter, *CssFilter;

/**
 *  Assoc structure.
 */
typedef struct CssAssoc_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSAssoc	c;

	int	sta_quark;
} _CssAssoc, *CssAssoc;

/**
 *  Stassoc structure.
 */
typedef struct CssStassoc_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSStassoc	c;

	int	sta_quark;
} _CssStassoc, *CssStassoc;

/**
 *  Affiliation struct.
 */
typedef struct CssAffiliation_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSAffiliation	c;

	// extra members for gbase internal use
	int	net_quark;
	int	sta_quark;
} _CssAffiliation, *CssAffiliation;

/**
 *  Stanet struct.
 */
typedef struct CssStanet_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSStanet	c;

	int	net_quark;
	int	sta_quark;
} _CssStanet, *CssStanet;

/**
 *  Hydro_features structure.
 */
typedef struct CssHydroFeatures_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSHydroFeatures c;
} _CssHydroFeatures, *CssHydroFeatures;

/**
 *  Infra_features structure.
 */
typedef struct CssInfraFeatures_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSInfraFeatures c;
} _CssInfraFeatures, *CssInfraFeatures;

/**
 *  Stamag structure.
 */
typedef struct CssStamag_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSStamag	c;

	int	sta_quark;
} _CssStamag, *CssStamag;

/**
 *  Netmag structure.
 */
typedef struct CssNetmag_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSNetmag	c;

	int	net_quark;
} _CssNetmag, *CssNetmag;

/**
 *  Ampdescript structure.
 */
typedef struct CssAmpdescript_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSAmpdescript	c;
} _CssAmpdescript, *CssAmpdescript;

/**
 *  Amplitude structure.
 */
typedef struct CssAmplitude_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSAmplitude	c;

	int	chan_quark;
	double	amp_cnts;	// measured amplitude
	double	amp_Nnms;	// measured amplitude (nominal)
	double	amp_nms;	// measured amplitude (corrected)
	double	zp_Nnms;	// zp measured amplitude (nominal)
	bool	box_location;
	double	boxtime;	// position (time) of the left side of the box
	double	boxmin;		// position (counts) of the bottom side
} _CssAmplitude, *CssAmplitude;

typedef struct CssStaconf_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSStaconf	c;

	int	staname_quark;
	int	statype_quark;
	int	refsite_quark;
	int	refchan_quark;
	int	threecsite_quark;
	int	threecband_quark;
	int	lpsite_quark;
	int	lpband_quark;
} _CssStaconf, *CssStaconf;

typedef struct CssParrival_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSParrival	c;

	int	sta_quark;
} _CssParrival, *CssParrival;

typedef struct CssDynamic5_s
{
	GObjectPart	core;
	CssTablePart	css;
	CssDescription	*des;

	union {
	    double	d_data;
	    double	f_data;
	    long	l_data;
	    int		i_data;
	} data[5];
} _CssDynamic5, *CssDynamic5;

typedef struct CssDynamic10_s
{
	GObjectPart	core;
	CssTablePart	css;
	CssDescription	*des;

	union {
	    double	d_data;
	    double	f_data;
	    long	l_data;
	    int		i_data;
	} data[10];
} _CssDynamic10, *CssDynamic10;

typedef struct CssDynamic20_s
{
	GObjectPart	core;
	CssTablePart	css;
	CssDescription	*des;

	union {
	    double	d_data;
	    double	f_data;
	    long	l_data;
	    int		i_data;
	} data[20];
} _CssDynamic20, *CssDynamic20;

typedef struct CssDynamic40_s
{
	GObjectPart	core;
	CssTablePart	css;
	CssDescription	*des;

	union {
	    double	d_data;
	    double	f_data;
	    long	l_data;
	    int		i_data;
	} data[40];
} _CssDynamic40, *CssDynamic40;

typedef struct CssDynamic_s
{
	GObjectPart	core;
	CssTablePart	css;
	CssDescription	*des;

	union {
	    double	d_data;
	    double	f_data;
	    long	l_data;
	    int		i_data;
	} data[60];
} _CssDynamic, *CssDynamic;

/*
 * CSS structs added by Teleca System Design for bg_analyze
 */
/**
 * gards_bg_energy_cal structure.
 */
typedef struct CssGards_bg_energy_cal_s
{
   GObjectPart   core;
   CssTablePart  css;
   CSSGardsBgEnergyCal c;
} _CssGards_bg_energy_cal, *CssGards_bg_energy_cal;

/**
 * gards_bg_energy_cal_orig structure.
 */
typedef struct CssGards_bg_energy_cal_orig_s
{
   GObjectPart   core;
   CssTablePart  css;
   CSSGardsBgEnergyCalOrig c;
} _CssGards_bg_energy_cal_orig, *CssGards_bg_energy_cal_orig;

/**
 *  Gards_bg_proc_params structure.
 */
typedef struct CssGards_bg_proc_params_s
{
   GObjectPart   core;
   CssTablePart  css;
   CSSGardsBgProcParams c;
} _CssGards_bg_proc_params, *CssGards_bg_proc_params;

/**
 *  Gards_bg_proc_params_roi structure.
 */
typedef struct CssGards_bg_proc_params_roi_s
{
   GObjectPart   core;
   CssTablePart  css;
   CSSGardsBgProcParamsRoi c;
} _CssGards_bg_proc_params_roi, *CssGards_bg_proc_params_roi;

/*
 *  gards_roi_channels structure.
 */
typedef struct CssGards_roi_channels_s
{
   GObjectPart   core;
   CssTablePart  css;
   CSSGardsRoiChannels c;
} _CssGards_roi_channels, *CssGards_roi_channels;

/**
 *  Gards_bg_roi_counts structure.
 */
typedef struct CssGards_bg_roi_counts_s
{
   GObjectPart   core;
   CssTablePart  css;
   CSSGardsBgRoiCounts c;
} _CssGards_bg_roi_counts, *CssGards_bg_roi_counts;

/**
 *  CssGards_bg_roi_concs structure.
 */
typedef struct CssGards_bg_roi_concs_s
{
   GObjectPart   core;
   CssTablePart  css;
   CSSGardsBgRoiConcs c;
} _CssGards_bg_roi_concs, *CssGards_bg_roi_concs;

/**
 *  CssGards_bg_isotope_concs structure.
 */
typedef struct CssGards_bg_isotope_concs_s
{
   GObjectPart   core;
   CssTablePart  css;
   CSSGardsBgIsotopeConcs c;
} _CssGards_bg_isotope_concs, *CssGards_bg_isotope_concs;

/**
 *  gards_sample_status structure.
 */
typedef struct CssGards_sample_status_s
{
   GObjectPart   core;
   CssTablePart  css;
   CSSGardsSampleStatus c;
} _CssGards_sample_status, *CssGards_sample_status;

/**
 *  gards_sample_data structure.
 */
typedef struct CssGards_sample_data_s
{
   GObjectPart   core;
   CssTablePart  css;
   CSSGardsSampleData c;
} _CssGards_sample_data, *CssGards_sample_data;

/**
 * gards_bg_std_spectra_result structure.
 */
typedef struct CssGards_bg_std_spectra_result_s
{
   GObjectPart   core;
   CssTablePart  css;
   CSSGardsBgStdSpectraResult c;
} _CssGards_bg_std_spectra_result, *CssGards_bg_std_spectra_result;

/**
 * gards_bg_qc_result structure.
 */
typedef struct CssGards_bg_qc_result_s
{
   GObjectPart   core;
   CssTablePart  css;
   CSSGardsBgQcResult c;
} _CssGards_bg_qc_result, *CssGards_bg_qc_result;

/**
 * gards_roi_limits structure.
 */
typedef struct
{
   GObjectPart   core;
   CssTablePart  css;
   CSSGardsRoiLimits c;
} _CssGards_roi_limits, *CssGards_roi_limits;

/**
 * gards_efficiency_pairs structure used by the noble gas gui
 */
typedef struct 
{
   GObjectPart   core;
   CssTablePart  css;
   CSSGardsEfficiencyPairs c;
} _CssGards_efficiency_pairs, *CssGards_efficiency_pairs;

/**
 *  Qcdata structure.
 */
typedef struct CssQcdata_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSQcdata	c;

	int	sta_quark;
	int	chan_quark;
	int	sens_quark;
} _CssQcdata, *CssQcdata;

/**
 *  Qcmaskdef structure.
 */
typedef struct CssQcmaskdef_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSQcmaskdef	c;
} _CssQcmaskdef, *CssQcmaskdef;

/**
 *  Qcmaskinfo structure.
 */
typedef struct CssQcmaskinfo_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSQcmaskinfo	c;
} _CssQcmaskinfo, *CssQcmaskinfo;

/**
 *  Qcmaskseg structure.
 */
typedef struct CssQcmaskseg_s
{
	GObjectPart	core;
	CssTablePart	css;
	CSSQcmaskseg	c;
} _CssQcmaskseg, *CssQcmaskseg;

/* Start bg_analyze*/
CssGards_bg_energy_cal new_CssGards_bg_energy_cal(void);
CssGards_bg_energy_cal_orig new_CssGards_bg_energy_cal_orig(void);
CssGards_bg_proc_params new_CssGards_bg_proc_params(void);
CssGards_bg_proc_params_roi new_CssGards_bg_proc_params_roi(void);
CssGards_roi_channels new_CssGards_roi_channels(void);
CssGards_bg_roi_concs new_CssGards_bg_roi_concs(void);
CssGards_bg_roi_counts new_CssGards_bg_roi_counts(void);
CssGards_bg_isotope_concs new_CssGards_bg_isotope_concs(void);
CssGards_sample_status new_CssGards_sample_status(void);
CssGards_sample_data new_CssGards_sample_data(void);
CssGards_bg_std_spectra_result new_CssGards_bg_std_spectra_result(void);
CssGards_bg_qc_result new_CssGards_bg_qc_result(void);
CssGards_roi_limits new_CssGards_roi_limits(void);
/* End bg_analyze */

/* Start noble gas gui */
CssGards_efficiency_pairs new_CssGards_efficiency_pairs(void);
/* End noble gas gui */

CssArrival new_CssArrival(void);
CssQcdata  new_CssQcdata(void);
CssQcmaskdef new_CssQcmaskdef(void);
CssQcmaskinfo new_CssQcmaskinfo(void);
CssQcmaskseg new_CssQcmaskseg(void);
CssWfdisc new_CssWfdisc(void);
CssHistory new_CssHistory(void);
CssChanname new_CssChanname(void);
CssFrameproduct new_CssFrameproduct(void);
CssFpdescription new_CssFpdescription(void);
CssMd5_digest new_CssMd5_digest(void);
CssClf new_CssClf(void);
CssWaveinterval new_CssWaveinterval(void);
CssOutage new_CssOutage(void);
CssOrigin new_CssOrigin(void);
CssOrigerr new_CssOrigerr(void);
CssOrigaux new_CssOrigaux(void);
CssLastid new_CssLastid(void);
CssSensor new_CssSensor(void);
CssInstrument new_CssInstrument(void);
CssSitechan new_CssSitechan(void);
CssSite new_CssSite(void);
CssWftag new_CssWftag(void);
CssXtag new_CssXtag(void);
CssFsdisc new_CssFsdisc(void);
CssFsave new_CssFsave(void);
CssFsrecipe new_CssFsrecipe(void);
CssFstag new_CssFstag(void);
CssSpdisc new_CssSpdisc(void);
CssDervdisc new_CssDervdisc(void);
CssPmccRecipe new_CssPmccRecipe(void);
CssPick new_CssPick(void);
CssFilter new_CssFilter(void);
CssAssoc new_CssAssoc(void);
CssStassoc new_CssStassoc(void);
CssAffiliation new_CssAffiliation(void);
CssStanet new_CssStanet(void);
CssHydroFeatures new_CssHydroFeatures(void);
CssInfraFeatures new_CssInfraFeatures(void);
CssStamag new_CssStamag(void);
CssNetmag new_CssNetmag(void);
CssAmpdescript new_CssAmpdescript(void);
CssAmplitude new_CssAmplitude(void);
CssPmccFeatures new_CssPmccFeatures(void);
CssStaconf new_CssStaconf(void);
CssParrival new_CssParrival(void);
CssDynamic5 new_CssDynamic5(CssDescription *des);
CssDynamic10 new_CssDynamic10(CssDescription *des);
CssDynamic20 new_CssDynamic20(CssDescription *des);
CssDynamic40 new_CssDynamic40(CssDescription *des);
CssDynamic new_CssDynamic(CssDescription *des);


/* Start bg_analyze */
int new_CssGards_bg_energy_cals(int num, CssGards_bg_energy_cal *tables);
int new_CssGards_bg_proc_paramss(int num, CssGards_bg_proc_params *tables);
int new_CssGards_bg_proc_params_rois(int num, CssGards_bg_proc_params_roi *tables);
int new_CssGards_roi_channelss(int num, CssGards_roi_channels *tables);
int new_CssGards_bg_roi_concss(int num, CssGards_bg_roi_concs *tables);
int new_CssGards_bg_roi_countss(int num, CssGards_bg_roi_counts *tables);
int new_CssGards_bg_isotope_concss(int num, CssGards_bg_isotope_concs *tables);
int new_CssGards_sample_statuss(int num, CssGards_sample_status *tables);
int new_CssGards_sample_datas(int num, CssGards_sample_data *tables);
int new_CssGards_bg_std_spectra_results(int num, CssGards_bg_std_spectra_result *tables);
int new_CssGards_bg_qc_results(int num, CssGards_bg_qc_result *tables);
int new_CssGards_roi_limitss(int num, CssGards_roi_limits *tables);
/* End bg_analyze */


/* Start noble gas gui */
int new_CssGards_efficiency_pairss(int num, CssGards_efficiency_pairs *tables);
/* End noble gas gui */


int new_CssArrivals(int num, CssArrival *tables);
int new_CssQcdatas(int num, CssQcdata *tables);
int new_CssQcmaskdefs(int num, CssQcmaskdef *tables);
int new_CssQcmaskinfos(int num, CssQcmaskinfo *tables);
int new_CssQcmasksegs(int num, CssQcmaskseg *tables);
int new_CssWfdiscs(int num, CssWfdisc *tables);
int new_CssHistorys(int num, CssHistory *tables);
int new_CssChannames(int num, CssChanname *tables);
int new_CssFrameproducts (int num, CssFrameproduct *tables);
int new_CssFpdescriptions (int num, CssFpdescription *tables);
int new_CssMd5_digests(int num, CssMd5_digest *tables);
int new_CssClfs(int num, CssClf *tables);
int new_CssWaveintervals(int num, CssWaveinterval *tables);
int new_CssOutages(int num, CssOutage *tables);
int new_CssOrigins(int num, CssOrigin *tables);
int new_CssOrigerrs(int num, CssOrigerr *tables);
int new_CssOrigauxs(int num, CssOrigaux *tables);
int new_CssLastids(int num, CssLastid *tables);
int new_CssSensors(int num, CssSensor *tables);
int new_CssInstruments(int num, CssInstrument *tables);
int new_CssSitechans(int num, CssSitechan *tables);
int new_CssSites(int num, CssSite *tables);
int new_CssWftags(int num, CssWftag *tables);
int new_CssXtags(int num, CssXtag *tables);
int new_CssFsdiscs(int num, CssFsdisc *tables);
int new_CssFsaves(int num, CssFsave *tables);
int new_CssFsrecipes(int num, CssFsrecipe *tables);
int new_CssFstags(int num, CssFstag *tables);
int new_CssSpdiscs(int num, CssSpdisc *tables);
int new_CssDervdiscs(int num, CssDervdisc *tables);
int new_CssPmccRecipes(int num, CssPmccRecipe *tables);
int new_CssPmccFs(int num, CssPmccFeatures *tables);
int new_CssPicks(int num, CssPick *tables);
int new_CssFilters(int num, CssFilter *tables);
int new_CssAssocs(int num, CssAssoc *tables);
int new_CssGregions(int num, CssGregion *tables); 
int new_CssStassocs(int num, CssStassoc *tables);
int new_CssAffiliations(int num, CssAffiliation *tables);
int new_CssStanets(int num, CssStanet *tables);
int new_CssHydros(int num, CssHydroFeatures *tables);
int new_CssInfras(int num, CssInfraFeatures *tables);
int new_CssStamags(int num, CssStamag *tables);
int new_CssNetmags(int num, CssNetmag *tables);
int new_CssAmpdescripts(int num, CssAmpdescript *tables);
int new_CssAmplitudes(int num, CssAmplitude *tables);
int new_CssStaconfs(int num, CssStaconf *tables);
int new_CssParrivals(int num, CssParrival *tables);
int new_CssDynamic5s(CssDescription *des, int num, CssDynamic5 *dynamic5s);
int new_CssDynamic10s(CssDescription *des, int num,CssDynamic10 *dynamic10s);
int new_CssDynamic20s(CssDescription *des, int num,CssDynamic20 *dynamic20s);
int new_CssDynamic40s(CssDescription *des, int num,CssDynamic40 *dynamic40s);
int new_CssDynamics(CssDescription *des, int num, CssDynamic *dynamics);

#endif
