/*
 * FILE NAME  idcstreamlog.h
 *
 *
 * SYNOPSIS
 *      Prototypes and constants for the libidcstreamlog.a clients.
 *
 * AUTHORS
 *
 *      Martin Ertl, Jan Kianicka (2015-12-01)
 *
 * MODIFICATIONS
 *
 */

#ifndef IDCSTREAMLOG_H
#define IDCSTREAMLOG_H

/*
 * Preferred order of includes,
 * according to the Google Style Guide:
 *
 *      1. Public .h file we are extending (if any).
 * 	2. C system files.
 * 	3. Other libraries' .h files.
 * 	4. Our project's .h files.
 *
 * Order files alphabetically within each section.
 */

#include "idcstreamlog_logger.h"       /* idcstreamlog_logger_t, et al. */
#include "idcstreamlog_streamlogger.h" /* IdcStreamLog_StreamLogger */
#include "idcstreamlog_filelogger.h"   /* IdcStreamLog_SysLogger */
#include "idcstreamlog_syslogger.h"    /* IdcStreamLog_SysLogger */
#include "idcstreamlog_topic.h"        /* idcstreamlog_topic_t */
#include "idcstreamlog_systopic.h"     /* idcstreamlog_systopic_t */
#include "idcstreamlog_stdtopic.h"     /* idcstreamlog_stdtopic_t */
#include "idcstreamlog_manager.h"      /* idcstreamlog_manager_t */

/*** Macro definitions ******************************************************/

/**
 * Macro switched debug logging with variable arguments.
 *
 * Usage:
 *   FPRINTF((L_DBG, T_GEN, "Hello debug!\n"));
 *   FPRINTF((L_DG1, T_RUN, "var1=%d, var2=%d\n", var1, var2));
 *
 * Build with CFLAGS='-DDEBUG=n':
 *   n=0: disables debug macros
 *   n>0: enables debug macros
 */
#ifdef FPRINTF
#undef FPRINTF
#undef VFPRINTF
#endif

#if DEBUG
#define FPRINTF(args) fprintf args
#define VFPRINTF(stream, fmt, ap) vfprintf(stream, fmt, ap)
#else
#define FPRINTF(args)
#define VFPRINTF(args)
#endif

/*** Type definitions *******************************************************/

/*** Global objects *********************************************************/

/*** Prototypes *************************************************************/

/* Interface function declarations */

/**
 * Constructor
 */
void idcstreamlog_init_manager(idcstreamlog_manager_t *mgr);

/**
 * Accessor/setter functions.
 */
idcstreamlog_systopic_t *idcstreamlog_get_applog(char const *topic);
idcstreamlog_systopic_t *idcstreamlog_get_liblog(char const *topic);

idcstreamlog_stdtopic_t *idcstreamlog_get_std();
idcstreamlog_stdtopic_t *idcstreamlog_get_prclog();

#endif
