/*
 * FILE NAME  idcstreamlog_filelogger.h
 *
 *
 * SYNOPSIS
 *      Prototypes and constants for the libidcstreamlog.a clients.
 *
 * AUTHORS
 *
 *      Martin Ertl, Jan Kianicka (2015-11-18)
 *
 * MODIFICATIONS
 *
 */

#ifndef IDCSTREAMLOG_FILELOGGER_H
#define IDCSTREAMLOG_FILELOGGER_H

/*
 * Preferred order of includes,
 * according to the Google Style Guide:
 *
 *      1. Public .h file we are extending (if any).
 * 	2. C system files.
 * 	3. Other libraries' .h files.
 * 	4. Our project's .h files.
 *
 * Order files alphabetically within each section.
 */

#include "idcstreamlog_logger.h" /* Base class */

#include <stdarg.h>              /* va_list */
#include <stdio.h>               /* FILE */

#include "idcstreamlog_core.h"   /* idcstreamlog_severity_t */

/*** Type definitions *******************************************************/

typedef struct idcstreamlog_filelogger_       idcstreamlog_filelogger_t;
typedef struct idcstreamlog_filelogger_class_ idcstreamlog_filelogger_class_k;

/*** Idcstreamlog_Filelogger class ******************************************/

/* Structure definitions */

/**
 * Virtual function table (vtable) structure.
 */
struct idcstreamlog_filelogger_class_
{
    /* Creation functions */
    idcstreamlog_filelogger_t *(*new)(char const *name, char const *pathspecs);
    idcstreamlog_filelogger_t *(*bless)(idcstreamlog_filelogger_t *self);
    idcstreamlog_filelogger_t *(*construct)(idcstreamlog_filelogger_t *self,
					    char const *name,
					    char const *pathspecs);
    idcstreamlog_logger_t *(*destruct)(idcstreamlog_logger_t *self);
    /* Builder functions */
    /* Accessor/setter functions */
    /* Service functions */
    void (*open)(idcstreamlog_filelogger_t *self);
    void (*close)(idcstreamlog_filelogger_t *self);
    void (*write)(idcstreamlog_filelogger_t *self,
		  char const *topic, idcstreamlog_severity_t,
		  char const *fmt, va_list ap);
    void (*rotate)(idcstreamlog_filelogger_t *self);
};

/* Global object declarations */

/**
 * Global class object.
 */
extern idcstreamlog_filelogger_class_k IdcStreamLog_FileLogger;

#endif
