/*
 * FILE NAME  idcstreamlog_logger.h
 *
 *
 * SYNOPSIS
 *      Prototypes and constants for the libidcstreamlog.a clients.
 *
 * AUTHORS
 *
 *      Martin Ertl, Jan Kianicka (2015-11-17)
 *
 * MODIFICATIONS
 *
 */

#ifndef IDCSTREAMLOG_LOGGER_H
#define IDCSTREAMLOG_LOGGER_H

/*
 * Preferred order of includes,
 * according to the Google Style Guide:
 *
 *      1. Public .h file we are extending (if any).
 * 	2. C system files.
 * 	3. Other libraries' .h files.
 * 	4. Our project's .h files.
 *
 * Order files alphabetically within each section.
 */

#include <stdarg.h>            /* va_list */

#include "idcstreamlog_core.h" /* idcstreamlog_severity_t */

/*** Type definitions *******************************************************/

/**
 * Abstract base class.
 */
typedef struct idcstreamlog_logger_       idcstreamlog_logger_t;
typedef struct idcstreamlog_logger_class_ idcstreamlog_logger_class_k;

/*** IdcStreamLogLogger class ***********************************************/

/* Structure definitions */

/**
 * Virtual function table (vtable) structure.
 */
struct idcstreamlog_logger_class_
{
    /* Creation functions */
    idcstreamlog_logger_t *(*new)(char const *name);
    idcstreamlog_logger_t *(*bless)(idcstreamlog_logger_t *self);
    idcstreamlog_logger_t *(*construct)(idcstreamlog_logger_t *self,
					const char *name);
    idcstreamlog_logger_t *(*destruct)(idcstreamlog_logger_t *self);
    /* Builder functions */
    /* Accessor/setter functions */
    /* Service functions */
    void (*open)(idcstreamlog_logger_t *self);
    void (*close)(idcstreamlog_logger_t *self);
    void (*write)(idcstreamlog_logger_t *self,
		  char const *topic, idcstreamlog_severity_t s,
		  char const *fmt, va_list ap);
    void (*rotate)(idcstreamlog_logger_t *self);
};

/* Global object declarations */

/**
 * Global class object.
 */
extern idcstreamlog_logger_class_k IdcStreamLog_Logger;

/* Interface (selector) function declarations */

/**
 * Virtual destructor.
 */
idcstreamlog_logger_t *
idcstreamlog_logger_destruct(idcstreamlog_logger_t *self);

/**
 * Polymorphic de-allocator.
 */
void idcstreamlog_logger_delete(idcstreamlog_logger_t **self);

/**
 * Builder functions.
 */

/**
 * Accessor/setter functions.
 */

/**
 * Service functions.
 */
void idcstreamlog_logger_open(idcstreamlog_logger_t *self);
void idcstreamlog_logger_close(idcstreamlog_logger_t *self);
void idcstreamlog_logger_write(idcstreamlog_logger_t *self,
			       char const *topic, idcstreamlog_severity_t s,
			       char const *fmt, ...);
void idcstreamlog_logger_vwrite(idcstreamlog_logger_t *self,
				char const *topic, idcstreamlog_severity_t s,
				char const *fmt, va_list ap);
void idcstreamlog_logger_rotate(idcstreamlog_logger_t *self);

/* Interface function declarations */

/**
 * Accessor/setter functions.
 */
char const *idcstreamlog_logger_get_name(idcstreamlog_logger_t *self);

#endif
