/*
 * FILE NAME  idcstreamlog_manager.h
 *
 *
 * SYNOPSIS
 *      Prototypes and constants for the libidcstreamlog.a clients.
 *
 * AUTHORS
 *
 *      Martin Ertl, Jan Kianicka (2015-11-26)
 *
 * MODIFICATIONS
 *
 */

#ifndef IDCSTREAMLOG_MANAGER_H
#define IDCSTREAMLOG_MANAGER_H

/*
 * Preferred order of includes,
 * according to the Google Style Guide:
 *
 *      1. Public .h file we are extending (if any).
 * 	2. C system files.
 * 	3. Other libraries' .h files.
 * 	4. Our project's .h files.
 *
 * Order files alphabetically within each section.
 */

#include "idcstreamlog_systopic.h" /* idcstreamlog_systopic_t */
#include "idcstreamlog_logger.h"   /* idcstreamlog_logger_t */
#include "idcstreamlog_core.h"     /* idcstreamlog_severity_t */

/*** Type definitions *******************************************************/

/**
 * Base types.
 */
typedef struct idcstreamlog_manager_       idcstreamlog_manager_t;
typedef struct idcstreamlog_manager_class_ idcstreamlog_manager_class_k;

/*** IdcStreamLog_Manager class *********************************************/

/* Structure definitions */

/**
 * Virtual function table (vtable) structure.
 */
struct idcstreamlog_manager_class_
{
    /* Creation functions */
    idcstreamlog_manager_t *(*new)(char const *name);
    idcstreamlog_manager_t *(*bless)(idcstreamlog_manager_t *self);
    idcstreamlog_manager_t *(*construct)(idcstreamlog_manager_t *self,
					 char const *name);
    idcstreamlog_manager_t *(*destruct)(idcstreamlog_manager_t *self);
    /* Builder functions */
    void (*add_topic)(idcstreamlog_manager_t *self,
		      idcstreamlog_topic_t *t);
    void (*unlink_topic)(idcstreamlog_manager_t *self,
			 idcstreamlog_topic_t *t);
    void (*add_logger)(idcstreamlog_manager_t *self, idcstreamlog_logger_t *l,
		       char const *priospecs);
    void (*unlink_logger)(idcstreamlog_manager_t *self,
			  idcstreamlog_logger_t *l);
    /* Accessor/setter functions */
    /* Service functions */
    void (*open)(idcstreamlog_manager_t *self);
    void (*close)(idcstreamlog_manager_t *self);
    void (*rotate)(idcstreamlog_manager_t *self);
};

/* Global object declarations */

/**
 * Global class object.
 */
extern idcstreamlog_manager_class_k IdcStreamLog_Manager;

/* Interface (selector) function declarations */

/**
 * Virtual destructor.
 */
idcstreamlog_manager_t *
idcstreamlog_manager_destruct(idcstreamlog_manager_t *self);

/**
 * Polymorphic de-allocator.
 */
void idcstreamlog_manager_delete(idcstreamlog_manager_t **self);

/**
 * Builder functions.
 */
void idcstreamlog_manager_add_topic(idcstreamlog_manager_t *self,
				    idcstreamlog_topic_t *t);
void idcstreamlog_manager_unlink_topic(idcstreamlog_manager_t *self,
				       idcstreamlog_topic_t *t);
void idcstreamlog_manager_add_logger(idcstreamlog_manager_t *self,
				     idcstreamlog_logger_t *l,
				     char const *priospecs);
void idcstreamlog_manager_unlink_logger(idcstreamlog_manager_t *self,
					idcstreamlog_logger_t *l);
/**
 * Accessor/setter functions.
 */
idcstreamlog_topic_t *
idcstreamlog_manager_get_topic(idcstreamlog_manager_t *self,
			       char const *name);

/**
 * Service functions.
 */
void idcstreamlog_manager_open(idcstreamlog_manager_t *self);
void idcstreamlog_manager_close(idcstreamlog_manager_t *self);
void idcstreamlog_manager_rotate(idcstreamlog_manager_t *self);

/* Interface function declarations */

/**
 * Accessor/setter functions.
 */
char const *idcstreamlog_manager_get_name(idcstreamlog_manager_t *self);

#endif
