/*
 * FILE NAME  idcstreamlog_stdcookie.h
 *
 *
 * SYNOPSIS
 *      Prototypes and constants for the libidcstreamlog.a clients.
 *
 * AUTHORS
 *
 *      Martin Ertl, Jan Kianicka (2015-11-21)
 *
 * MODIFICATIONS
 *
 */

#ifndef IDCSTREAMLOG_STDCOOKIE_H
#define IDCSTREAMLOG_STDCOOKIE_H

/*
 * Preferred order of includes,
 * according to the Google Style Guide:
 *
 *      1. Public .h file we are extending (if any).
 * 	2. C system files.
 * 	3. Other libraries' .h files.
 * 	4. Our project's .h files.
 *
 * Order files alphabetically within each section.
 */

#include "idcstreamlog_cookie.h"     /* Base class */

#include "idcstreamlog_systopic.h"   /* idcstreamlog_systopic_t */
#include "idcstreamlog_logger.h"     /* idcstreamlog_logger_t */
#include "idcstreamlog_core.h"       /* idcstreamlog_severity_t */

/*** Type definitions *******************************************************/

/**
 * Abstract base class.
 */
typedef struct idcstreamlog_stdcookie_       idcstreamlog_stdcookie_t;
typedef struct idcstreamlog_stdcookie_class_ idcstreamlog_stdcookie_class_k;

/*** IdcStreamLog_StdCookie class *******************************************/

/* Structure definitions */

/**
 * Virtual function table (vtable) structure.
 */
struct idcstreamlog_stdcookie_class_
{
    /* Creation functions */
    idcstreamlog_stdcookie_t *(*new)(char const **topic,
				     idcstreamlog_severity_t severity,
				     idcstreamlog_systopic_t *systopic);
    idcstreamlog_stdcookie_t *(*bless)(idcstreamlog_stdcookie_t *self);
    idcstreamlog_cookie_t *(*construct)(idcstreamlog_stdcookie_t *self,
					char const **topic,
					idcstreamlog_severity_t severity,
					idcstreamlog_systopic_t *systopic);
    idcstreamlog_cookie_t *(*destruct)(idcstreamlog_stdcookie_t *self);
    /* Builder functions */
    void (*add_logger)(idcstreamlog_cookie_t *self, idcstreamlog_logger_t *l);
    void (*unlink_logger)(idcstreamlog_cookie_t *self,
			  idcstreamlog_logger_t *l);
    /* Accessor/setter functions */
    idcstreamlog_logger_t *(*find_logger)(idcstreamlog_cookie_t *self,
					  idcstreamlog_logger_t *lin);
    /* Service functions */
};

/* Global object declarations */

/**
 * Global class object.
 */
extern idcstreamlog_stdcookie_class_k IdcStreamLog_StdCookie;

/* Interface (selector) function declarations */

/* Interface function declarations */

#endif
