/*
 * FILE NAME  idcstreamlog_streamlogger.h
 *
 *
 * SYNOPSIS
 *      Prototypes and constants for the libidcstreamlog.a clients.
 *
 * AUTHORS
 *
 *      Martin Ertl, Jan Kianicka (2015-11-17)
 *
 * MODIFICATIONS
 *
 */

#ifndef IDCSTREAMLOG_STREAMLOGGER_H
#define IDCSTREAMLOG_STREAMLOGGER_H

/*
 * Preferred order of includes,
 * according to the Google Style Guide:
 *
 *      1. Public .h file we are extending (if any).
 * 	2. C system files.
 * 	3. Other libraries' .h files.
 * 	4. Our project's .h files.
 *
 * Order files alphabetically within each section.
 */

#include "idcstreamlog_logger.h" /* Base class */

#include <stdarg.h>              /* va_list */
#include <stdio.h>               /* FILE */

#include "idcstreamlog_core.h"   /* idcstreamlog_severity_t */

/*** Type definitions *******************************************************/

typedef struct idcstreamlog_streamlogger_       idcstreamlog_streamlogger_t;
typedef struct idcstreamlog_streamlogger_class_ idcstreamlog_streamlogger_class_k;

/*** IdcStreamLog_StreamLogger class ****************************************/

/* Structure definitions */

/**
 * Virtual function table (vtable) structure.
 */
struct idcstreamlog_streamlogger_class_
{
    /* Creation functions */
    idcstreamlog_streamlogger_t *(*new)(char const *name, FILE *stream);
    idcstreamlog_streamlogger_t *(*bless)(idcstreamlog_streamlogger_t *self);
    idcstreamlog_streamlogger_t *(*construct)(idcstreamlog_streamlogger_t *self,
					      char const *name, FILE *stream);
    idcstreamlog_logger_t *(*destruct)(idcstreamlog_logger_t *self);
    /* Builder functions */
    /* Accessor/setter functions */
    /* Service functions */
    void (*open)(idcstreamlog_logger_t *self);
    void (*close)(idcstreamlog_logger_t *self);
    void (*write)(idcstreamlog_streamlogger_t *self,
		  char const *topic, idcstreamlog_severity_t,
		  char const *fmt, va_list ap);
    void (*rotate)(idcstreamlog_logger_t *self);
};

/* Global object declarations */

/**
 * Global class object.
 */
extern idcstreamlog_streamlogger_class_k IdcStreamLog_StreamLogger;

#endif
