#ifndef _LOGFILES_H
#define _LOGFILES_H

/**
 * @author    Gerald Klinkl
 *
 * Revision 1.13  2013-07-12 gerald
 * Move WFDISC_WCS30_IN and WFDISC_WCS30 defines to logfiles.h
 * Write 7 significant digits for ncalib to wfdisc
 * (see ISI-126)
 *
 * Revision 1.12  2013-04-03 gerald
 * Fix include dependencies
 */

#include "cd_common.h"

/**
 *  CSS 3.0 Wfdisc structure.
 *  char[7], VARCHAR2(6) sta; Station. Initial value = "-".
 *  char[9], VARCHAR2(8) chan; Channel. Initial value = "-".
 *  double, FLOAT(53) time; Epoch time of first sample in file.
         Initial value = -9999999999.999.
 *  uint64_t, NUMBER(10) wfid; Waveform id. Initial value = -1.
 *  uint32_t, NUMBER(8) chanid; Channel operation id. Initial value = -1.
 *  uint32_t, NUMBER(8) jdate; Julian date. Initial value = -1.
 *  double, FLOAT(53) endtime; Time + (nsamp-1)/samprate.
            Initial value = -9999999999.999.
 *  uint32_t, NUMBER(8) nsamp; Number of samples. Initial value = -1.
 *  float, FLOAT(24) samprate; Sampling rate in samples/second.
           Initial value = -1.
 *  float, FLOAT(24) calib; Nominal calibration. Initial value = 0.
 *  float, FLOAT(24) calper; Nominal calibration period. Initial value = -1.
 *  char[7], VARCHAR(6) instype; Instrument code. Initial value = "-".
 *  char[2], VARCHAR(1) segtype; Indexing method. Initial value = "-".
 *  char[3], VARCHAR(2) datatype; Numeric storage. Initial value = "-".
 *  char[2], VARCHAR(1) clip; Clipped flag. Initial value = "-".
 *  char[65], VARCHAR(64) dir; Directory. Initial value = "-".
 *  char[33], VARCHAR(32) dfile; Data file. Initial value = "-".
 *  uint64_t, NUMBER(10) foff; Byte offset. Initial value = 0.
 *  uint64_t, NUMBER(10) commid; Comment id. Initial value = -1.
 *  char[18], DATE lddate; Load date. Initial value = "-".
 */

#define WFDISC_WCS30A "%-6.6s %-8.8s %17.5f %8ld %8ld %8ld %17.5f %8ld %11.7f %16.7g %16.6f %-6.6s %1s %-2.2s %1s %-64.64s %-32.32s %10ld %8ld %-17.17s\n"

/* Not all values are read when reading a wfdisc file!! */
#define WFDISC_WCS30_IN "%6s %8s %lf %*d %ld %*d %lf %ld %lf %f %f %*s %*c %2s %c %64s %32s %ld %*d %*s\n"

/* ==== Function prototypes ================================================= */

#define REOPEN_OLD_FILES 1

extern void printChannelParsingCodeAsText(uint32_t code, FILE *fp);
extern void printFrameParsingCodeAsText(uint32_t code, FILE *fp);
extern void printCD11ChannelStatusAsText(uint32_t code, FILE *fp);
extern void printCDqualityFlagAsText(uint16_t cdflag, FILE *fp);
extern void initIdxFile(configParams_t *pConfigData, const char *appName);
extern int syncFiles(station_t *pStation, const unsigned char isCR,
                     const int forceReopen, time_t oldDate);
extern int saveData(station_t *pStation, const char *buffer,
                    const int bytesRead, const int bytesWritten,
                    const uint16_t event,
                    const unsigned char isCR, char tbsType);
extern void addInfo2Files(station_t *pStation, const uint16_t event);
extern void addName2TxtFile(station_t *pStation, const char *name);
/*@null@*//*@dependent@*/
extern FILE *openOld(station_t *pStation, time_t oldDate, uint32_t what);
extern int getFileName(station_t *pStation, time_t datetime, uint32_t what,
                       /*@out@*/char *filename, size_t *lenNameBuf);

extern void addChanName2ClfFile(station_t *pStation, uint16_t index,
                                const char *scName);
/*@dependent@*/
extern const char *getCD1StatusAsText(int code);
/*@dependent@*/
extern const char *getCD11DataStatusText(int code);
/*@dependent@*/
extern const char *getCD11ChannelSecurityText(int code);
/*@dependent@*/
extern const char *getCD11MiscText(int code);
/*@dependent@*/
extern const char *getCD11VoltageText(int code);
/*@dependent@*/
extern const char *getChannelParsingCodeAsText(uint32_t code);
/*@dependent@*/
extern const char *getFrameParsingCodeAsText(uint32_t code);

extern int saveInUserFormat(station_t *pStation, uint32_t offsetInBinfile);
extern void initUserFormat(configParams_t *pConfigData);

#endif /* _LOGFILES_H */

